@@ -24,11 +24,11 @@ class FeatherCache(Cache):
         else:
             self.filename = f"FeatherCache-{uuid.uuid4()}.feather"
 
-    def fit(self, data: pd.DataFrame) -> None:
+    def fit(self, data: Optional[pd.DataFrame] = None) -> None:
         if not self.is_cached():
             data.reset_index(drop=True).to_feather(self.filename)
 
-    def run(self, data: Optional[pd.DataFrame]) -> pd.DataFrame:
+    def run(self, data: Optional[pd.DataFrame] = None) -> pd.DataFrame:
         if self.is_cached():
             return pd.read_feather(self.filename)
         else:
