@@ -14,11 +14,11 @@ class InMemoryCache(Cache):
     def __init__(self):
         self._data = None
 
-    def fit(self, data: pd.DataFrame) -> None:
+    def fit(self, data: Optional[pd.DataFrame] = None) -> None:
         if self._data is None:
             self._data = data
 
-    def run(self, data: Optional[pd.DataFrame]) -> pd.DataFrame:
+    def run(self, data: Optional[pd.DataFrame] = None) -> pd.DataFrame:
         if self.is_cached():
             return self._data
         else:
