@@ -1,6 +1,7 @@
 import pandas as pd
 
 from pipedown.nodes.base.loader import Loader
+from pipedown.utils.urls import get_node_url
 
 
 class SqlAlchemyLoader(Loader):
@@ -22,13 +23,15 @@ class SqlAlchemyLoader(Loader):
         Dictionary of arguments to be used to template the query
     """
 
+    CODE_URL = get_node_url("loaders/sqlalchemy_loader.py")
+
     def __init__(self, engine, query_filename, query_kwargs={}):
         self.engine = engine
         self.query = self.format_query(query_filename, query_kwargs)
 
     def format_query(self, query_filename, query_kwargs):
         with open(query_filename, "r") as fid:
-            if query_args:
+            if query_kwargs:
                 from jinja2 import Template
 
                 return Template(fid.read()).render(**query_kwargs)
